@@ -1,11 +1,11 @@
-__version__ = "0.5.0"
+__version__ = "0.5.2"
 
 from .ssim import ssim, multi_scale_ssim, SSIMLoss, MultiScaleSSIMLoss
 from .msid import MSID
 from .fid import FID
 from .kid import KID
 from .tv import TVLoss, total_variation
-from .gmsd import GMSDLoss, MultiScaleGMSDLoss
+from .gmsd import gmsd, multi_scale_gmsd, GMSDLoss, MultiScaleGMSDLoss
 from .gs import GS
 from .isc import IS, inception_score
 from .vif import VIFLoss, vif_p
@@ -14,3 +14,5 @@ from .perceptual import StyleLoss, ContentLoss, LPIPS, DISTS
 from .psnr import psnr
 from .fsim import fsim, FSIMLoss
 from .vsi import vsi, VSILoss
+from .mdsi import mdsi, MDSILoss
+from .haarpsi import haarpsi, HaarPSILoss
\ No newline at end of file
