@@ -8,6 +8,7 @@ Credits:
     https://github.com/bukalapak/pybrisque
 """
 from typing import Union, Tuple
+import warnings
 import torch
 from torch.nn.modules.loss import _Loss
 from torch.utils.model_zoo import load_url
@@ -23,21 +24,31 @@ def brisque(x: torch.Tensor,
     r"""Interface of BRISQUE index.
 
     Args:
-        x: Batch of images. Required to be 2D (H, W), 3D (C,H,W) or 4D (N,C,H,W), channels first.
+        x: Tensor with shape (H, W), (C, H, W) or (N, C, H, W). RGB channel order for colour images.
         kernel_size: The side-length of the sliding window used in comparison. Must be an odd value.
         kernel_sigma: Sigma of normal distribution.
-        data_range: Value range of input images (usually 1.0 or 255).
+        data_range: Maximum value range of input images (usually 1.0 or 255).
         reduction: Reduction over samples in batch: "mean"|"sum"|"none".
         interpolation: Interpolation to be used for scaling.
 
     Returns:
         Value of BRISQUE index.
 
+    Note:
+        The back propagation is not available using torch=1.5.0 due to bug in argmin/argmax back propagation.
+        Update the torch and torchvision to the latest versions.
+
     References:
         .. [1] Anish Mittal et al. "No-Reference Image Quality Assessment in the Spatial Domain",
         https://live.ece.utexas.edu/publications/2012/TIP%20BRISQUE.pdf
     """
-    _validate_input(input_tensors=x, allow_5d=False)
+    if '1.5.0' in torch.__version__:
+        warnings.warn(f'BRISQUE does not support back propagation due to bug in torch={torch.__version__}.'
+                      f'Update torch to the latest version to access full functionality of the BRIQSUE.'
+                      f'More info is available at https://github.com/photosynthesis-team/piq/pull/79 and'
+                      f'https://github.com/pytorch/pytorch/issues/38869.')
+
+    _validate_input(input_tensors=x, allow_5d=False, kernel_size=kernel_size)
     x = _adjust_dimensions(input_tensors=x)
 
     assert data_range >= x.max(), f'Expected data range greater or equal maximum value, got {data_range} and {x.max()}.'
@@ -64,7 +75,7 @@ def brisque(x: torch.Tensor,
 
 class BRISQUELoss(_Loss):
     r"""Creates a criterion that measures the BRISQUE score for input :math:`x`.
-    :math:`x` is tensor of 2D (H, W), 3D (C,H,W) or 4D (N,C,H,W), channels first.
+    :math:`x` is tensor of 2D (H, W), 3D (C, H, W) or 4D (N, C, H, W).
     The sum operation still operates over all the elements, and divides by :math:`n`.
     The division by :math:`n` can be avoided by setting ``reduction = 'sum'``.
 
@@ -82,7 +93,7 @@ class BRISQUELoss(_Loss):
         interpolation: Interpolation to be used for scaling.
 
     Shape:
-        - Input: Required to be 2D (H, W), 3D (C,H,W) or 4D (N,C,H,W), channels first.
+        - Input: Required to be 2D (H, W), 3D (C, H, W) or 4D (N, C, H, W). RGB channel order for colour images.
 
     Examples::
         >>> loss = BRISQUELoss()
@@ -91,6 +102,10 @@ class BRISQUELoss(_Loss):
         >>> output = loss(prediction)
         >>> output.backward()
 
+    Note:
+        The back propagation is not available using torch=1.5.0 due to bug in argmin/argmax back propagation.
+        Update the torch and torchvision to the latest versions.
+
     References:
         .. [1] Anish Mittal et al. "No-Reference Image Quality Assessment in the Spatial Domain",
         https://live.ece.utexas.edu/publications/2012/TIP%20BRISQUE.pdf
@@ -168,7 +183,7 @@ def _aggd_parameters(x: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor, torch
 
 
 def _natural_scene_statistics(luma: torch.Tensor, kernel_size: int = 7, sigma: float = 7. / 6) -> torch.Tensor:
-    kernel = gaussian_filter(size=kernel_size, sigma=sigma).view(1, 1, kernel_size, kernel_size).to(luma)
+    kernel = gaussian_filter(kernel_size=kernel_size, sigma=sigma).view(1, 1, kernel_size, kernel_size).to(luma)
     C = 1
     mu = F.conv2d(luma, kernel, padding=kernel_size // 2)
     mu_sq = mu ** 2
@@ -176,9 +191,8 @@ def _natural_scene_statistics(luma: torch.Tensor, kernel_size: int = 7, sigma: f
     std = ((std - mu_sq).abs().sqrt())
 
     luma_nrmlzd = (luma - mu) / (std + C)
-    features = []
     alpha, sigma = _ggd_parameters(luma_nrmlzd)
-    features.extend((alpha, sigma.pow(2)))
+    features = [alpha, sigma.pow(2)]
 
     shifts = [(0, 1), (1, 0), (1, 1), (-1, 1)]
 
