@@ -24,8 +24,9 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
     
 
     Args:
-        x: Batch of predicted images with shape (batch_size x channels x H x W)
-        y: Batch of target images with shape  (batch_size x channels x H x W)
+        x: Predicted images. Shape (H, W), (C, H, W) or (N, C, H, W).
+        y: Target images. Shape (H, W), (C, H, W) or (N, C, H, W).
+        reduction: Reduction over samples in batch: "mean"|"sum"|"none"
         data_range: Value range of input images (usually 1.0 or 255). Default: 1.0
         chromatic: Flag to compute FSIMc, which also takes into account chromatic components
         scales: Number of wavelets used for computation of phase congruensy maps
@@ -51,13 +52,9 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
     _validate_input(input_tensors=(x, y), allow_5d=False)
     x, y = _adjust_dimensions(input_tensors=(x, y))
     
-    # Scale to [0., 1.] range
-    x = x / float(data_range)
-    y = y / float(data_range)
-    
     # Rescale to [0, 255] range, because all constant are calculated for this factor
-    x = x * 255
-    y = y * 255
+    x = (x / float(data_range)) * 255
+    y = (y / float(data_range)) * 255
     
     # Apply average pooling
     kernel_size = max(1, round(min(x.shape[-2:]) / 256))
@@ -132,7 +129,7 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     """Creates a stack of filters used for computation of phase congruensy maps
     
     Args:
-        x: Tensor with shape Bx1xHxW
+        x: Tensor with shape (N, 1, H, W).
         scales: Number of wavelets
         orientations: Number of filter orientations
         min_length: Wavelength of smallest scale filter
@@ -147,7 +144,7 @@ def _construct_filters(x: torch.Tensor, scales: int = 4, orientations: int = 4,
             at which we set the noise threshold point, below which phase
             congruency values get penalized.
         """
-    B, _, H, W = x.shape
+    N, _, H, W = x.shape
 
     # Calculate the standard deviation of the angular Gaussian function
     # used to construct filters in the freq. plane.
@@ -217,7 +214,7 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     r"""Compute Phase Congruence for a batch of greyscale images
 
     Args:
-        x: Tensor with shape Bx1xHxW
+        x: Tensor with shape (N, 1, H, W).
         levels: Number of wavelet scales
         orientations: Number of filter orientations
         min_length: Wavelength of smallest scale filter
@@ -237,7 +234,7 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     """
     EPS = torch.finfo(x.dtype).eps
 
-    B, _, H, W = x.shape
+    N, _, H, W = x.shape
 
     # Fourier transform
     imagefft = torch.rfft(x, 2, onesided=False)
@@ -248,7 +245,7 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     filters_ifft = torch.ifft(torch.stack([filters, torch.zeros_like(filters)], dim=-1), 2)[..., 0] * math.sqrt(H * W)
     
     # Convolve image with even and odd filters
-    even_odd = torch.ifft(imagefft * filters.unsqueeze(-1), 2).view(B, orientations, scales, H, W, 2)
+    even_odd = torch.ifft(imagefft * filters.unsqueeze(-1), 2).view(N, orientations, scales, H, W, 2)
 
     # Amplitude of even & odd filter response. An = sqrt(real^2 + imag^2)
     an = torch.sqrt(torch.sum(even_odd ** 2, dim=-1))
@@ -289,8 +286,8 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     # The estimate of noise power is obtained by dividing the mean squared
     # energy value by the mean squared filter value
     
-    abs_eo = torch.sqrt(torch.sum(even_odd[:, :, :1, ...] ** 2, dim=-1)).reshape(B, orientations, 1, 1, H * W)
-    median_e2n = torch.median(abs_eo ** 2, dim=-1, keepdims=True).values
+    abs_eo = torch.sqrt(torch.sum(even_odd[:, :, :1, ...] ** 2, dim=-1)).reshape(N, orientations, 1, 1, H * W)
+    median_e2n = torch.median(abs_eo ** 2, dim=-1, keepdim=True).values
 
     mean_e2n = - median_e2n / math.log(0.5)
 
@@ -303,7 +300,7 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     
     sum_an2 = torch.sum(filters_ifft ** 2, dim=-3, keepdim=True)
     
-    sum_ai_aj = torch.zeros(B, orientations, 1, H, W).to(x)
+    sum_ai_aj = torch.zeros(N, orientations, 1, H, W).to(x)
     for s in range(scales - 1):
         sum_ai_aj = sum_ai_aj + (filters_ifft[:, :, s: s + 1] * filters_ifft[:, :, s + 1:]).sum(dim=-3, keepdim=True)
             
@@ -340,7 +337,7 @@ def _phase_congruency(x: torch.Tensor, scales: int = 4, orientations: int = 4,
     return result_pc.unsqueeze(1)
 
 
-def _lowpassfilter(size: Union[int, Tuple[int, int]], cutoff: float, n: int) -> torch.Tensor:
+def _lowpassfilter(size: Tuple[int, int], cutoff: float, n: int) -> torch.Tensor:
     r"""
     Constructs a low-pass Butterworth filter.
     Args:
@@ -374,7 +371,6 @@ class FSIMLoss(_Loss):
     use function `fsim` instead.
 
     Args:
-        chromatic: Flag to compute FSIMc, which also takes into account chromatic components
         reduction: Specifies the reduction to apply to the output:
             ``'none'`` | ``'mean'`` | ``'sum'``. ``'none'``: no reduction will be applied,
             ``'mean'``: the sum of the output will be divided by the number of
@@ -382,6 +378,7 @@ class FSIMLoss(_Loss):
         data_range: The difference between the maximum and minimum of the pixel value,
             i.e., if for image x it holds min(x) = 0 and max(x) = 1, then data_range = 1.
             The pixel value interval of both input and output should remain the same.
+        chromatic: Flag to compute FSIMc, which also takes into account chromatic components
         scales: Number of wavelets used for computation of phase congruensy maps
         orientations: Number of filter orientations used for computation of phase congruensy maps
         min_length: Wavelength of smallest scale filter
@@ -394,8 +391,8 @@ class FSIMLoss(_Loss):
             threshold  point, below which phase congruency values get penalized.
 
     Shape:
-        - Input: Required to be 2D (H, W), 3D (C,H,W), 4D (N,C,H,W) or 5D (N,C,H,W,2), channels first.
-        - Target: Required to be 2D (H, W), 3D (C,H,W), 4D (N,C,H,W) or 5D (N,C,H,W,2), channels first.
+        - Input: Required to be 2D (H, W), 3D (C, H, W) or 4D (N, C, H, W). RGB channel order for colour images.
+        - Target: Required to be 2D (H, W), 3D (C, H, W) or 4D (N, C, H, W). RGB channel order for colour images.
 
     Examples::
 
@@ -409,10 +406,9 @@ class FSIMLoss(_Loss):
         .. [1] Anish Mittal et al. "No-Reference Image Quality Assessment in the Spatial Domain",
         https://live.ece.utexas.edu/publications/2012/TIP%20BRISQUE.pdf
         """
-    def __init__(self, data_range: Union[int, float] = 1., reduction: str = 'mean', scales: int = 4,
-                 orientations: int = 4, min_length: int = 6, mult: int = 2, sigma_f: float = 0.55,
-                 delta_theta: float = 1.2, k: float = 2.0) -> None:
-
+    def __init__(self, reduction: str = 'mean', data_range: Union[int, float] = 1., chromatic: bool = True,
+                 scales: int = 4, orientations: int = 4, min_length: int = 6, mult: int = 2,
+                 sigma_f: float = 0.55, delta_theta: float = 1.2, k: float = 2.0) -> None:
         super().__init__()
         self.data_range = data_range
         self.reduction = reduction
@@ -420,8 +416,9 @@ class FSIMLoss(_Loss):
         # Save function with predefined parameters, rather than parameters themself
         self.fsim = functools.partial(
             fsim,
-            data_range=data_range,
             reduction=reduction,
+            data_range=data_range,
+            chromatic=chromatic,
             scales=scales,
             orientations=orientations,
             min_length=min_length,
