@@ -7,10 +7,10 @@ https://arxiv.org/pdf/1802.02664.pdf
 from typing import Optional, Tuple
 from multiprocessing import Pool
 
-from scipy.spatial.distance import cdist
-
 import torch
+import gudhi
 import numpy as np
+from scipy.spatial.distance import cdist
 
 from piq.base import BaseFeatureMetric
 
@@ -43,8 +43,7 @@ def relative(intervals: np.ndarray, alpha_max: float, i_max: int = 100) -> np.nd
         rlt[0] = 1.0
         return rlt
 
-    persistence_intervals_ext = persistence_intervals + [[0, alpha_max]]
-    persistence_intervals_ext = np.array(persistence_intervals_ext)
+    persistence_intervals_ext = np.array(persistence_intervals + [[0, alpha_max]])
     persistence_intervals = np.array(persistence_intervals)
 
     # Change in the value of beta_1 may happen only at the boundary points
@@ -67,10 +66,10 @@ def relative(intervals: np.ndarray, alpha_max: float, i_max: int = 100) -> np.nd
 def lmrk_table(witnesses: np.ndarray, landmarks: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
     r"""Construct an input for the gudhi.WitnessComplex function.
     Args:
-        witnesses: Array of size w x d, containing witnesses
-        landmarks: Array of size l x d, containing landmarks
+        witnesses: Array with shape (w, d), containing witnesses.
+        landmarks: Array with shape (l, d), containing landmarks.
     Returns:
-        distances: 3D array of size w x l x 2. It satisfies the property that
+        distances: 3D array with shape (w, l, 2). It satisfies the property that
             distances[i, :, :] is [idx_i, dists_i], where dists_i are the sorted distances
             from the i-th witness to each point in L and idx_i are the indices of the corresponding points
             in L, e.g., D[i, :, :] = [[0, 0.1], [1, 0.2], [3, 0.3], [2, 0.4]]
@@ -90,25 +89,13 @@ def witness(
     """Compute the persistence intervals for the dataset of features using the witness complex.
 
     Args:
-        features: Array of shape (N_samples, data_dim) representing the dataset.
+        features: Array with shape (N_samples, data_dim) representing the dataset.
         sample_size: Number of landmarks to use on each iteration.
         gamma: Parameter determining maximum persistence value. Default is `1.0 / 128 * N_imgs / 5000`
 
     Returns
         A list of persistence intervals and the maximal persistence value.
     """
-    # Install gudhi only if needed
-    try:
-        import gudhi
-    except ImportError as e:
-        import six
-        error = e.__class__(
-            "You are likely missing your GUDHI installation, "
-            "you should visit http://gudhi.gforge.inria.fr/python/latest/installation.html "
-            "for further instructions.\nIf you use conda, you can use\nconda install -c conda-forge gudhi"
-        )
-        six.raise_from(error, e)
-
     N = features.shape[0]
     if gamma is None:
         gamma = 1.0 / 128 * N / 5000
@@ -133,22 +120,29 @@ class GS(BaseFeatureMetric):
     r"""Interface of Geometry Score.
     It's computed for a whole set of data and can use features from encoder instead of images itself to decrease
     computation cost. GS can compare two data distributions with different number of samples.
-    But dimensionalities should match, otherwise it won't be possible to correctly compute statistics.
+    Dimensionalities of features should match, otherwise it won't be possible to correctly compute statistics.
 
     Args:
-        predicted_features (torch.Tensor): Low-dimension representation of predicted image set.
+        predicted_features: Low-dimension representation of predicted image set.
             Shape (N_pred, encoder_dim)
-        target_features (torch.Tensor): Low-dimension representation of target image set.
+        target_features: Low-dimension representation of target image set.
             Shape (N_targ, encoder_dim)
 
     Returns:
-        score (torch.Tensor): Scalar value of the distance between image sets.
+        score: Scalar value of the distance between image sets.
 
     References:
         .. [1] Khrulkov V., Oseledets I. (2018).
         Geometry score: A method for comparing generative adversarial networks.
         arXiv preprint, 2018.
         https://arxiv.org/abs/1802.02664
+
+    Note:
+        Computation is heavily CPU dependent, adjust `num_workers` parameter according to your system configuration.
+        GS metric requiers `gudhi` library which is not installed by default.
+        For conda, write: `conda install -c conda-forge gudhi`,
+            otherwise follow installation guide: http://gudhi.gforge.inria.fr/python/latest/installation.html
+
     """
     def __init__(self, sample_size: int = 64, num_iters: int = 1000, gamma: Optional[float] = None,
                  i_max: int = 100, num_workers: int = 4) -> None:
