@@ -63,7 +63,7 @@ def test_ssim_measure_is_one_for_equal_tensors(target: torch.Tensor, device: str
     measure = ssim(prediction, target, data_range=1., reduction='none')
     assert torch.allclose(measure, torch.ones_like(measure)), f'If equal tensors are passed SSIM must be equal to 1 ' \
                                                               f'(considering floating point error up to 1 * 10^-6), '\
-                                                              f'got {measure + 1}'
+                                                              f'got {measure}'
 
 
 @pytest.mark.parametrize(
@@ -88,7 +88,7 @@ def test_ssim_measure_is_less_or_equal_to_one(ones_zeros_4d_5d: Tuple[torch.Tens
     ones = ones_zeros_4d_5d[0].to(device)
     zeros = ones_zeros_4d_5d[1].to(device)
     measure = ssim(ones, zeros, data_range=1., reduction='none')
-    assert (measure <= 1).all(), f'SSIM must be <= 1, got {measure}'
+    assert torch.less_equal(measure, 1).all(), f'SSIM must be <= 1, got {measure}'
 
 
 def test_ssim_raises_if_tensors_have_different_shapes(prediction_target_4d_5d: Tuple[torch.Tensor,
@@ -164,7 +164,7 @@ def test_ssim_raise_if_wrong_value_is_estimated(test_images: Tuple[torch.Tensor,
         tf_target = tf.convert_to_tensor(target.permute(0, 2, 3, 1).numpy())
         with tf.device('/CPU'):
             tf_ssim = torch.tensor(tf.image.ssim(tf_prediction, tf_target, max_val=255).numpy()).to(piq_ssim)
-        match_accuracy = 2e-5 + 1e-8
+        match_accuracy = 2e-4 + 1e-8
         assert torch.allclose(piq_ssim, tf_ssim, rtol=0, atol=match_accuracy), \
             f'The estimated value must be equal to tensorflow provided one' \
             f'(considering floating point operation error up to {match_accuracy}), ' \
@@ -276,7 +276,7 @@ def test_ssim_loss_raise_if_wrong_value_is_estimated(test_images: Tuple[torch.Te
         tf_target = tf.convert_to_tensor(target.permute(0, 2, 3, 1).numpy())
         with tf.device('/CPU'):
             tf_ssim = torch.tensor(tf.image.ssim(tf_prediction, tf_target, max_val=255).numpy()).mean().to(device)
-        match_accuracy = 2e-5 + 1e-8
+        match_accuracy = 2e-4 + 1e-8
         assert torch.isclose(ssim_loss, 1. - tf_ssim, rtol=0, atol=match_accuracy), \
             f'The estimated value must be equal to tensorflow provided one' \
             f'(considering floating point operation error up to {match_accuracy}), ' \
@@ -389,8 +389,7 @@ def test_multi_scale_ssim_raise_if_wrong_value_is_estimated(test_images: Tuple[t
         with tf.device('/CPU'):
             tf_ms_ssim = torch.tensor(tf.image.ssim_multiscale(tf_prediction, tf_target, max_val=255,
                                                                power_factors=scale_weights).numpy()).to(device)
-        number_of_weights = 5.
-        match_accuracy = number_of_weights * 1e-5 + 1e-8
+        match_accuracy = 1e-5 + 1e-8
         assert torch.allclose(piq_ms_ssim, tf_ms_ssim, rtol=0, atol=match_accuracy), \
             f'The estimated value must be equal to tensorflow provided one' \
             f'(considering floating point operation error up to {match_accuracy}), ' \
@@ -516,8 +515,7 @@ def test_multi_scale_ssim_loss_raise_if_wrong_value_is_estimated(test_images: Li
             tf_ms_ssim = torch.tensor(tf.image.ssim_multiscale(tf_prediction, tf_target,
                                                                power_factors=scale_weights,
                                                                max_val=255).numpy()).mean().to(device)
-        number_of_weights = len(piq_loss.scale_weights)
-        match_accuracy = number_of_weights * 1e-5 + 1e-8
+        match_accuracy = 1e-5 + 1e-8
         assert torch.isclose(piq_ms_ssim_loss, 1. - tf_ms_ssim, rtol=0, atol=match_accuracy), \
             f'The estimated value must be equal to tensorflow provided one' \
             f'(considering floating point operation error up to {match_accuracy}), ' \
